@@ -35,7 +35,6 @@
 #include "monit.h"
 #include "protocol.h"
 #include "process.h"
-#include "ssl.h"
 #include "engine.h"
 
 
@@ -55,9 +54,9 @@ static void _gc_action(Action_T *);
 static void _gc_eventaction(EventAction_T *);
 static void _gcpdl(Dependant_T *);
 static void _gcso(Size_T *);
-static void _gcnetlinkstatus(NetLinkStatus_T *);
-static void _gcnetlinkspeed(NetLinkSpeed_T *);
-static void _gcnetlinksaturation(NetLinkSaturation_T *);
+static void _gclinkstatus(LinkStatus_T *);
+static void _gclinkspeed(LinkSpeed_T *);
+static void _gclinksaturation(LinkSaturation_T *);
 static void _gcbandwidth(Bandwidth_T *);
 static void _gcmatch(Match_T *);
 static void _gcchecksum(Checksum_T *);
@@ -67,6 +66,8 @@ static void _gcuid(Uid_T *);
 static void _gcgid(Gid_T *);
 static void _gcpid(Pid_T *);
 static void _gcppid(Pid_T *);
+static void _gcfsflag(Fsflag_T *);
+static void _gcnonexist(Nonexist_T *);
 static void _gcgrc(Generic_T *);
 static void _gcath(Auth_T *);
 static void _gc_mmonit(Mmonit_T *);
@@ -85,90 +86,70 @@ static void _gc_request(Request_T *);
 
 
 void gc() {
-
-        destroy_hosts_allow();
-
-        if(Run.doprocess) {
+        Engine_destroyHostsAllow();
+        if (Run.doprocess) {
                 delprocesstree(&oldptree, &oldptreesize);
                 delprocesstree(&ptree, &ptreesize);
         }
-
-        if(servicelist)
+        if (servicelist)
                 _gc_service_list(&servicelist);
-
-        if(servicegrouplist)
+        if (servicegrouplist)
                 _gc_servicegroup(&servicegrouplist);
-
-        if(Run.credentials)
-                _gcath(&Run.credentials);
-
-        if(Run.maillist)
+        if (Run.httpd.credentials)
+                _gcath(&Run.httpd.credentials);
+        if (Run.maillist)
                 gc_mail_list(&Run.maillist);
-
-        if(Run.mailservers)
+        if (Run.mailservers)
                 _gc_mail_server(&Run.mailservers);
-
-        if(Run.mmonits)
+        if (Run.mmonits)
                 _gc_mmonit(&Run.mmonits);
-
-        if(Run.eventlist)
+        if (Run.eventlist)
                 gc_event(&Run.eventlist);
-
         FREE(Run.eventlist_dir);
         FREE(Run.mygroup);
-        FREE(Run.httpsslpem);
-        FREE(Run.httpsslclientpem);
-        FREE(Run.bind_addr);
+        if (Run.httpd.flags & Httpd_Net) {
+                FREE(Run.httpd.socket.net.address);
+                FREE(Run.httpd.socket.net.ssl.pem);
+                FREE(Run.httpd.socket.net.ssl.clientpem);
+        } else if (Run.httpd.flags & Httpd_Unix) {
+                FREE(Run.httpd.socket.unix.path);
+        }
         FREE(Run.MailFormat.from);
         FREE(Run.MailFormat.subject);
         FREE(Run.MailFormat.message);
         FREE(Run.mail_hostname);
-
 }
 
 
 void gc_mail_list(Mail_T *m) {
-
         ASSERT(m);
-
-        if((*m)->next)
+        if ((*m)->next)
                 gc_mail_list(&(*m)->next);
-
         FREE((*m)->to);
         FREE((*m)->from);
         FREE((*m)->replyto);
         FREE((*m)->subject);
         FREE((*m)->message);
         FREE(*m);
-
 }
 
 
 void gccmd(command_t *c) {
-
-        int i;
-
         ASSERT(c&&*c);
-
-        for(i = 0; (*c)->arg[i]; i++)
+        for (int i = 0; (*c)->arg[i]; i++)
                 FREE((*c)->arg[i]);
         FREE(*c);
-
 }
 
 
 void gc_event(Event_T *e) {
-
         ASSERT(e&&*e);
-
-        if((*e)->next)
+        if ((*e)->next)
                 gc_event(&(*e)->next);
-
         (*e)->action = NULL;
         FREE((*e)->source);
         FREE((*e)->message);
         FREE(*e);
-
 }
 
 
@@ -176,21 +157,15 @@ void gc_event(Event_T *e) {
 
 
 static void _gc_service_list(Service_T *s) {
-
         ASSERT(s&&*s);
-
-        if((*s)->next)
+        if ((*s)->next)
                 _gc_service_list(&(*s)->next);
-
         _gc_service(&(*s));
-
 }
 
 
 static void _gc_service(Service_T *s) {
-
         ASSERT(s&&*s);
-
         if ((*s)->program) {
                 if ((*s)->program->P)
                         Process_free(&(*s)->program->P);
@@ -201,147 +176,103 @@ static void _gc_service(Service_T *s) {
                 StringBuffer_free(&((*s)->program->output));
                 FREE((*s)->program);
         }
-
-        if((*s)->portlist)
+        if ((*s)->portlist)
                 _gcppl(&(*s)->portlist);
-
-        if((*s)->filesystemlist)
+        if ((*s)->socketlist)
+                _gcppl(&(*s)->socketlist);
+        if ((*s)->filesystemlist)
                 _gcfilesystem(&(*s)->filesystemlist);
-
-        if((*s)->icmplist)
+        if ((*s)->icmplist)
                 _gcicmp(&(*s)->icmplist);
-
-        if((*s)->maillist)
+        if ((*s)->maillist)
                 gc_mail_list(&(*s)->maillist);
-
-        if((*s)->resourcelist)
+        if ((*s)->resourcelist)
                 _gcpql(&(*s)->resourcelist);
-
-        if((*s)->timestamplist)
+        if ((*s)->timestamplist)
                 _gcptl(&(*s)->timestamplist);
-
-        if((*s)->actionratelist)
+        if ((*s)->actionratelist)
                 _gcparl(&(*s)->actionratelist);
-
-        if((*s)->sizelist)
+        if ((*s)->sizelist)
                 _gcso(&(*s)->sizelist);
-
-        if((*s)->netlinkstatuslist)
-                _gcnetlinkstatus(&(*s)->netlinkstatuslist);
-
-        if((*s)->netlinkspeedlist)
-                _gcnetlinkspeed(&(*s)->netlinkspeedlist);
-
-        if((*s)->netlinksaturationlist)
-                _gcnetlinksaturation(&(*s)->netlinksaturationlist);
-
-        if((*s)->uploadbyteslist)
+        if ((*s)->linkstatuslist)
+                _gclinkstatus(&(*s)->linkstatuslist);
+        if ((*s)->linkspeedlist)
+                _gclinkspeed(&(*s)->linkspeedlist);
+        if ((*s)->linksaturationlist)
+                _gclinksaturation(&(*s)->linksaturationlist);
+        if ((*s)->uploadbyteslist)
                 _gcbandwidth(&(*s)->uploadbyteslist);
-
-        if((*s)->uploadpacketslist)
+        if ((*s)->uploadpacketslist)
                 _gcbandwidth(&(*s)->uploadpacketslist);
-
-        if((*s)->downloadbyteslist)
+        if ((*s)->downloadbyteslist)
                 _gcbandwidth(&(*s)->downloadbyteslist);
-
-        if((*s)->downloadpacketslist)
+        if ((*s)->downloadpacketslist)
                 _gcbandwidth(&(*s)->downloadpacketslist);
-
-        if((*s)->matchlist)
+        if ((*s)->matchlist)
                 _gcmatch(&(*s)->matchlist);
-
-        if((*s)->matchignorelist)
+        if ((*s)->matchignorelist)
                 _gcmatch(&(*s)->matchignorelist);
-
-        if((*s)->checksum)
+        if ((*s)->checksum)
                 _gcchecksum(&(*s)->checksum);
-
-        if((*s)->perm)
+        if ((*s)->perm)
                 _gcperm(&(*s)->perm);
-
         if ((*s)->statuslist)
                 _gcstatus(&(*s)->statuslist);
-
-        if ((*s)->every.type == EVERY_CRON || (*s)->every.type == EVERY_NOTINCRON)
+        if ((*s)->every.type == Every_Cron || (*s)->every.type == Every_NotInCron)
                 FREE((*s)->every.spec.cron);
-
-        if((*s)->uid)
+        if ((*s)->uid)
                 _gcuid(&(*s)->uid);
-
-        if((*s)->euid)
+        if ((*s)->euid)
                 _gcuid(&(*s)->euid);
-
-        if((*s)->gid)
+        if ((*s)->gid)
                 _gcgid(&(*s)->gid);
-
-        if((*s)->pidlist)
+        if ((*s)->pidlist)
                 _gcpid(&(*s)->pidlist);
-
-        if((*s)->ppidlist)
+        if ((*s)->ppidlist)
                 _gcppid(&(*s)->ppidlist);
-
-        if((*s)->dependantlist)
+        if ((*s)->fsflaglist)
+                _gcfsflag(&(*s)->fsflaglist);
+        if ((*s)->nonexistlist)
+                _gcnonexist(&(*s)->nonexistlist);
+        if ((*s)->dependantlist)
                 _gcpdl(&(*s)->dependantlist);
-
-        if((*s)->start)
+        if ((*s)->start)
                 gccmd(&(*s)->start);
-
-        if((*s)->stop)
+        if ((*s)->stop)
                 gccmd(&(*s)->stop);
-
-        if((*s)->action_DATA)
+        if ((*s)->action_DATA)
                 _gc_eventaction(&(*s)->action_DATA);
-
-        if((*s)->action_EXEC)
+        if ((*s)->action_EXEC)
                 _gc_eventaction(&(*s)->action_EXEC);
-
-        if((*s)->action_INVALID)
+        if ((*s)->action_INVALID)
                 _gc_eventaction(&(*s)->action_INVALID);
-
-        if((*s)->action_NONEXIST)
-                _gc_eventaction(&(*s)->action_NONEXIST);
-
-        if((*s)->action_FSFLAG)
-                _gc_eventaction(&(*s)->action_FSFLAG);
-
-        if((*s)->action_MONIT_START)
+        if ((*s)->action_MONIT_START)
                 _gc_eventaction(&(*s)->action_MONIT_START);
-
-        if((*s)->action_MONIT_STOP)
+        if ((*s)->action_MONIT_STOP)
                 _gc_eventaction(&(*s)->action_MONIT_STOP);
-
-        if((*s)->action_MONIT_RELOAD)
+        if ((*s)->action_MONIT_RELOAD)
                 _gc_eventaction(&(*s)->action_MONIT_RELOAD);
-
-        if((*s)->action_ACTION)
+        if ((*s)->action_ACTION)
                 _gc_eventaction(&(*s)->action_ACTION);
-
-        if((*s)->eventlist)
+        if ((*s)->eventlist)
                 gc_event(&(*s)->eventlist);
-
-        if((*s)->inf) {
-                if ((*s)->type == TYPE_NET)
-                        NetStatistics_free(&((*s)->inf->priv.net.stats));
+        if ((*s)->inf) {
+                if ((*s)->type == Service_Net)
+                        Link_free(&((*s)->inf->priv.net.stats));
                 FREE((*s)->inf);
         }
-
         FREE((*s)->name);
         FREE((*s)->path);
-
         (*s)->next = NULL;
-
         FREE(*s);
-
 }
 
 
 static void _gc_servicegroup(ServiceGroup_T *sg) {
         ASSERT(sg && *sg);
-
-        if((*sg)->next)
+        if ((*sg)->next)
                 _gc_servicegroup(&(*sg)->next);
-
-        if((*sg)->members)
+        if ((*sg)->members)
                 _gc_servicegroup_member(&(*sg)->members);
         FREE((*sg)->name);
         FREE(*sg);
@@ -350,20 +281,16 @@ static void _gc_servicegroup(ServiceGroup_T *sg) {
 
 static void _gc_servicegroup_member(ServiceGroupMember_T *m) {
         ASSERT(m && *m);
-
-        if((*m)->next)
+        if ((*m)->next)
                 _gc_servicegroup_member(&(*m)->next);
-
         FREE((*m)->name);
         FREE(*m);
 }
 
 
 static void _gc_request(Request_T *r) {
-
         ASSERT(r);
-
-        if((*r)->url)
+        if ((*r)->url)
                 _gc_url(&(*r)->url);
 #ifdef HAVE_REGEX_H
         if ((*r)->regex)
@@ -371,14 +298,11 @@ static void _gc_request(Request_T *r) {
 #endif
         FREE((*r)->regex);
         FREE(*r);
-
 }
 
 
 static void _gc_url(URL_T *url) {
-
         ASSERT(url);
-
         FREE((*url)->url);
         FREE((*url)->protocol);
         FREE((*url)->user);
@@ -387,64 +311,49 @@ static void _gc_url(URL_T *url) {
         FREE((*url)->path);
         FREE((*url)->query);
         FREE(*url);
-
 }
 
 
 static void _gc_mail_server(MailServer_T *s) {
-
         if (! s || ! *s)
                 return;
-
         if ((*s)->next)
                 _gc_mail_server(&(*s)->next);
-
         FREE((*s)->host);
         FREE((*s)->username);
         FREE((*s)->password);
         FREE((*s)->ssl.certmd5);
         FREE((*s)->ssl.clientpemfile);
         FREE(*s);
-
 }
 
 
 static void _gc_action(Action_T *a) {
-
         ASSERT(a&&*a);
-
-        if((*a)->exec)
+        if ((*a)->exec)
                 gccmd(&(*a)->exec);
         FREE(*a);
-
 }
 
 
 static void _gc_eventaction(EventAction_T *e) {
-
         ASSERT(e&&*e);
-
         _gc_action(&(*e)->failed);
         _gc_action(&(*e)->succeeded);
         FREE(*e);
-
 }
 
 
 static void _gcppl(Port_T *p) {
-
         ASSERT(p&&*p);
-
-        if((*p)->next)
+        if ((*p)->next)
                 _gcppl(&(*p)->next);
-
-        if((*p)->action)
+        if ((*p)->action)
                 _gc_eventaction(&(*p)->action);
-        if((*p)->generic)
+        if ((*p)->generic)
                 _gcgrc(&(*p)->generic);
-        if((*p)->url_request)
+        if ((*p)->url_request)
                 _gc_request(&(*p)->url_request);
-
         FREE((*p)->request);
         FREE((*p)->hostname);
         FREE((*p)->pathname);
@@ -464,118 +373,89 @@ static void _gcppl(Port_T *p) {
 
 
 static void _gcfilesystem(Filesystem_T *d) {
-
         ASSERT(d&&*d);
-
-        if((*d)->next)
+        if ((*d)->next)
                 _gcfilesystem(&(*d)->next);
-
-        if((*d)->action)
+        if ((*d)->action)
                 _gc_eventaction(&(*d)->action);
-
         FREE(*d);
-
 }
 
 
 static void _gcicmp(Icmp_T *i) {
-
         ASSERT(i&&*i);
-
-        if((*i)->next)
+        if ((*i)->next)
                 _gcicmp(&(*i)->next);
-
-        if((*i)->action)
+        if ((*i)->action)
                 _gc_eventaction(&(*i)->action);
-
         FREE(*i);
-
 }
 
 
 static void _gcpql(Resource_T *q) {
-
         ASSERT(q);
-
-        if((*q)->next)
+        if ((*q)->next)
                 _gcpql(&(*q)->next);
-
-        if((*q)->action)
+        if ((*q)->action)
                 _gc_eventaction(&(*q)->action);
-
         FREE(*q);
-
 }
 
 
 static void _gcptl(Timestamp_T *p) {
         ASSERT(p);
-
-        if((*p)->next)
+        if ((*p)->next)
                 _gcptl(&(*p)->next);
-
-        if((*p)->action)
+        if ((*p)->action)
                 _gc_eventaction(&(*p)->action);
-
         FREE(*p);
 }
 
 
 static void _gcparl(ActionRate_T *ar) {
         ASSERT(ar);
-
-        if((*ar)->next)
+        if ((*ar)->next)
                 _gcparl(&(*ar)->next);
-
-        if((*ar)->action)
+        if ((*ar)->action)
                 _gc_eventaction(&(*ar)->action);
-
         FREE(*ar);
 }
 
 
 static void _gcso(Size_T *s) {
-
         ASSERT(s);
-
-        if((*s)->next)
+        if ((*s)->next)
                 _gcso(&(*s)->next);
-
-        if((*s)->action)
+        if ((*s)->action)
                 _gc_eventaction(&(*s)->action);
-
         FREE(*s);
-
 }
 
-static void _gcnetlinkstatus(NetLinkStatus_T *l) {
+static void _gclinkstatus(LinkStatus_T *l) {
         ASSERT(l);
-
-        if((*l)->next)
-                _gcnetlinkstatus(&(*l)->next);
-        if((*l)->action)
+        if ((*l)->next)
+                _gclinkstatus(&(*l)->next);
+        if ((*l)->action)
                 _gc_eventaction(&(*l)->action);
         FREE(*l);
 }
 
 
-static void _gcnetlinkspeed(NetLinkSpeed_T *l) {
+static void _gclinkspeed(LinkSpeed_T *l) {
         ASSERT(l);
-
-        if((*l)->next)
-                _gcnetlinkspeed(&(*l)->next);
-        if((*l)->action)
+        if ((*l)->next)
+                _gclinkspeed(&(*l)->next);
+        if ((*l)->action)
                 _gc_eventaction(&(*l)->action);
         FREE(*l);
 }
 
 
-static void _gcnetlinksaturation(NetLinkSaturation_T *l) {
+static void _gclinksaturation(LinkSaturation_T *l) {
         ASSERT(l);
-
-        if((*l)->next)
-                _gcnetlinksaturation(&(*l)->next);
-        if((*l)->action)
+        if ((*l)->next)
+                _gclinksaturation(&(*l)->next);
+        if ((*l)->action)
                 _gc_eventaction(&(*l)->action);
         FREE(*l);
 }
@@ -583,100 +463,78 @@ static void _gcnetlinksaturation(NetLinkSaturation_T *l) {
 
 static void _gcbandwidth(Bandwidth_T *b) {
         ASSERT(b);
-
-        if((*b)->next)
+        if ((*b)->next)
                 _gcbandwidth(&(*b)->next);
-        if((*b)->action)
+        if ((*b)->action)
                 _gc_eventaction(&(*b)->action);
         FREE(*b);
 }
 
 static void _gcmatch(Match_T *s) {
-
         ASSERT(s);
-
-        if((*s)->next)
+        if ((*s)->next)
                 _gcmatch(&(*s)->next);
-
-        if((*s)->action)
+        if ((*s)->action)
                 _gc_eventaction(&(*s)->action);
-
         FREE((*s)->match_path);
         FREE((*s)->match_string);
-
 #ifdef HAVE_REGEX_H
-        if((*s)->regex_comp) {
+        if ((*s)->regex_comp) {
                 regfree((*s)->regex_comp);
                 FREE((*s)->regex_comp);
         }
 #endif
-
         FREE(*s);
-
 }
 
 
 static void _gcchecksum(Checksum_T *s) {
         ASSERT(s);
-
         if ((*s)->action)
                 _gc_eventaction(&(*s)->action);
-
         FREE(*s);
 }
 
 
 static void _gcperm(Perm_T *s) {
-
         ASSERT(s);
-
-        if((*s)->action)
+        if ((*s)->action)
                 _gc_eventaction(&(*s)->action);
-
         FREE(*s);
-
 }
 
 
 static void _gcstatus(Status_T *s) {
-
         ASSERT(s);
-
-        if((*s)->next)
+        if ((*s)->next)
                 _gcstatus(&(*s)->next);
-        if((*s)->action)
+        if ((*s)->action)
                 _gc_eventaction(&(*s)->action);
         FREE(*s);
 }
 
 
 static void _gcuid(Uid_T *s) {
-
         ASSERT(s);
-
-        if((*s)->action)
+        if ((*s)->action)
                 _gc_eventaction(&(*s)->action);
-
         FREE(*s);
-
 }
 
 
 static void _gcgid(Gid_T *s) {
-
         ASSERT(s);
-
-        if((*s)->action)
+        if ((*s)->action)
                 _gc_eventaction(&(*s)->action);
-
         FREE(*s);
-
 }
 
 
 static void _gcpid(Pid_T *s) {
         ASSERT(s);
-        if((*s)->action)
+        if ((*s)->next)
+                _gcpid(&(*s)->next);
+        if ((*s)->action)
                 _gc_eventaction(&(*s)->action);
         FREE(*s);
 }
@@ -684,35 +542,50 @@ static void _gcpid(Pid_T *s) {
 
 static void _gcppid(Pid_T *s) {
         ASSERT(s);
-        if((*s)->action)
+        if ((*s)->next)
+                _gcppid(&(*s)->next);
+        if ((*s)->action)
+                _gc_eventaction(&(*s)->action);
+        FREE(*s);
+}
+
+
+static void _gcfsflag(Fsflag_T *s) {
+        ASSERT(s);
+        if ((*s)->next)
+                _gcfsflag(&(*s)->next);
+        if ((*s)->action)
+                _gc_eventaction(&(*s)->action);
+        FREE(*s);
+}
+
+
+static void _gcnonexist(Nonexist_T *s) {
+        ASSERT(s);
+        if ((*s)->next)
+                _gcnonexist(&(*s)->next);
+        if ((*s)->action)
                 _gc_eventaction(&(*s)->action);
         FREE(*s);
 }
 
 
 static void _gcpdl(Dependant_T *d) {
-
         ASSERT(d);
-
-        if((*d)->next)
+        if ((*d)->next)
                 _gcpdl(&(*d)->next);
-
         FREE((*d)->dependant);
         FREE(*d);
-
 }
 
 
 static void _gcgrc(Generic_T *g) {
-
         ASSERT(g);
-
-        if((*g)->next)
+        if ((*g)->next)
                 _gcgrc(&(*g)->next);
-
         FREE((*g)->send);
 #ifdef HAVE_REGEX_H
-        if ((*g)->expect!=NULL)
+        if ((*g)->expect != NULL)
                 regfree((*g)->expect);
 #endif
         FREE((*g)->expect);
@@ -722,33 +595,23 @@ static void _gcgrc(Generic_T *g) {
 
 
 static void _gcath(Auth_T *c) {
-
         ASSERT(c);
-
-        if((*c)->next)
+        if ((*c)->next)
                 _gcath(&(*c)->next);
-
         FREE((*c)->uname);
         FREE((*c)->passwd);
         FREE((*c)->groupname);
         FREE(*c);
-
 }
 
 
 static void _gc_mmonit(Mmonit_T *recv) {
-
         ASSERT(recv);
-
-        if((*recv)->next)
+        if ((*recv)->next)
                 _gc_mmonit(&(*recv)->next);
-
         _gc_url(&(*recv)->url);
-
         FREE((*recv)->ssl.certmd5);
         FREE((*recv)->ssl.clientpemfile);
         FREE(*recv);
-
 }
 
-
