@@ -30,37 +30,31 @@
 
 #include "protocol.h"
 
+// libmonit
+#include "exceptions/IOException.h"
+
+
 /**
- *  A simple 'SSH protocol version exchange' implemetation based on
- *  RFC (http://www.openssh.com/txt/draft-ietf-secsh-transport-14.txt)
+ *  A simple 'SSH protocol version exchange' implemetation based on RFC (http://www.openssh.com/txt/draft-ietf-secsh-transport-14.txt)
  *
  *  @file
  */
-int check_ssh(Socket_T socket) {
+void check_ssh(Socket_T socket) {
 
-  char  buf[STRLEN];
+        char  buf[STRLEN];
 
-  ASSERT(socket);
+        ASSERT(socket);
 
-  if(!socket_readln(socket, buf, sizeof(buf))) {
-    socket_setError(socket, "SSH: error receiving identification string -- %s", STRERROR);
-    return FALSE;
-  }
+        if (! Socket_readLine(socket, buf, sizeof(buf)))
+                THROW(IOException, "SSH: error receiving identification string -- %s", STRERROR);
 
-  if(! Str_startsWith(buf, "SSH-")) {
-    socket_setError(socket, "SSH: protocol error %s", buf);
-    return FALSE;
-  }
+        if (! Str_startsWith(buf, "SSH-"))
+                THROW(IOException, "SSH: protocol error %s", buf);
 
-  /* send identification string back to server */
-  if(socket_write(socket, buf, strlen(buf)) <= 0) {
-    socket_setError(socket, "SSH: error sending identification string -- %s", STRERROR);
-    return FALSE;
-  }
-
-  /* Read one extra line to prevent the "Read from socket failed" warning */
-  socket_readln(socket, buf, sizeof(buf));
-
-  return TRUE;
+        /* send identification string back to server */
+        if (Socket_write(socket, buf, strlen(buf)) <= 0)
+                THROW(IOException, "SSH: error sending identification string -- %s", STRERROR);
 
+        /* Read one extra line to prevent the "Read from socket failed" warning */
+        Socket_readLine(socket, buf, sizeof(buf));
 }
