@@ -89,9 +89,9 @@ char *Util_digest2Bytes(unsigned char *digest, int mdlen, MD_T result);
  * @param stream The stream from where the digests are computed
  * @param sha_resblock The buffer to write the SHA1 result to or NULL to skip the SHA1
  * @param md5_resblock The buffer to write the MD5 result to or NULL to skip the MD5
- * @return FALSE if failed, otherwise TRUE
+ * @return false if failed, otherwise true
  */
-int Util_getStreamDigests(FILE *stream, void *sha_resblock, void *md5_resblock);
+boolean_t Util_getStreamDigests(FILE *stream, void *sha_resblock, void *md5_resblock);
 
 
 /**
@@ -104,12 +104,12 @@ void Util_printHash(char *file);
 /**
  * Store the checksum of given file in supplied buffer
  * @param file The file for which to compute the checksum
- * @param hashtype The hash type (HASH_MD5 or HASH_SHA1)
+ * @param hashtype The hash type (Hash_Md5 or Hash_Sha1)
  * @param buf The buffer where the result will be stored
  * @param bufsize The size of the buffer
- * @return FALSE if failed, otherwise TRUE
+ * @return false if failed, otherwise true
  */
-int Util_getChecksum(char *file, int hashtype, char *buf, int bufsize);
+boolean_t Util_getChecksum(char *file, Hash_Type hashtype, char *buf, int bufsize);
 
 
 /**
@@ -132,10 +132,10 @@ Service_T Util_getService(const char *name);
 
 /**
  * @param name A service name as stated in the config file
- * @return TRUE if the service name exist in the
- * servicelist, otherwise FALSE
+ * @return true if the service name exist in the
+ * servicelist, otherwise false
  */
-int Util_existService(const char *name);
+boolean_t Util_existService(const char *name);
 
 
 /**
@@ -177,7 +177,7 @@ char *Util_monitId(char *idfile);
 /**
  * Open and read the pid from the given pidfile.
  * @param pidfile A pidfile with full path
- * @return the pid (TRUE) or FALSE if the pid could
+ * @return the pid or 0 if the pid could
  * not be read from the file
  */
 pid_t Util_getPid(char *pidfile);
@@ -186,19 +186,10 @@ pid_t Util_getPid(char *pidfile);
 /**
  * Check whether the process is running
  * @param s The service being checked
- * @param refresh TRUE to refresh the global ptree (useful for procmatch if process was mangled by monit in the same cycle such as by restart action) or FALSE to use cached ptree
+ * @param refresh true to refresh the global ptree (useful for procmatch if process was mangled by monit in the same cycle such as by restart action) or false to use cached ptree
  * @return The PID of the running running process or 0 if the process is not running.
  */
-int Util_isProcessRunning(Service_T s, int refresh);
-
-
-/**
- * Compute an uptime for a process based on the ctime
- * from the pidfile.
- * @param pidfile A process pidfile
- * @return an uptime
- */
-time_t Util_getProcessUptime(char *pidfile);
+int Util_isProcessRunning(Service_T s, boolean_t refresh);
 
 
 /**
@@ -216,7 +207,7 @@ char *Util_getUptime(time_t delta, char *sep);
  * @param url an url string to test
  * @return true if url is url safe otherwise false
  */
-int Util_isurlsafe(const char *url);
+boolean_t Util_isurlsafe(const char *url);
 
 /**
  * Escape an url string converting unsafe characters to a hex (%xx)
@@ -289,10 +280,10 @@ Auth_T Util_getUserCredentials(char *uname);
  * given username.
  * @param uname Username
  * @param outside The password to test
- * @return TRUE if the passwords match for the given uname otherwise
- * FALSE
+ * @return true if the passwords match for the given uname otherwise
+ * false
  */
-int Util_checkCredentials(char *uname, char *outside);
+boolean_t Util_checkCredentials(char *uname, char *outside);
 
 
 /**
@@ -305,9 +296,9 @@ void Util_resetInfo(Service_T s);
 /**
  * Are service status data available?
  * @param s The service to test
- * @return TRUE if available otherwise FALSE
+ * @return true if available otherwise false
  */
-int Util_hasServiceStatus(Service_T s);
+boolean_t Util_hasServiceStatus(Service_T s);
 
 
 /**
@@ -329,7 +320,7 @@ char *Util_getHTTPHostHeader(Socket_T s, char *hostBuf, int len);
  * @param rightExpression rval
  * @return the boolean value of the expression
  */
-int Util_evalQExpression(Operator_Type operator, long long left, long long right);
+boolean_t Util_evalQExpression(Operator_Type operator, long long left, long long right);
 
 
 /**
@@ -339,7 +330,7 @@ int Util_evalQExpression(Operator_Type operator, long long left, long long right
  * @param rightExpression rval
  * @return the boolean value of the expression
  */
-int Util_evalDoubleQExpression(Operator_Type operator, double left, double right);
+boolean_t Util_evalDoubleQExpression(Operator_Type operator, double left, double right);
 
 
 /*
@@ -394,16 +385,24 @@ StringBuffer_T Util_printEventratio(Action_T action, StringBuffer_T buf);
 StringBuffer_T Util_printRule(StringBuffer_T buf, EventAction_T action, const char *rule, ...);
 
 
+/**
+ * Print port IP version description
+ * @param p A port structure
+ * @return the socket IP version description
+ */
+const char *Util_portIpDescription(Port_T p);
+
+
 /**
  * Print port type description
  * @param p A port structure
  * @return the socket type description
  */
-char *Util_portTypeDescription(Port_T p);
+const char *Util_portTypeDescription(Port_T p);
 
 
 /**
- * Print full port description <INET|UNIX>\[<host>:<port>[request]\][via TCP|TCPSSL|UDP]
+ * Print full port description \[<host>\]:<port>[request][ via TCP|TCPSSL|UDP]
  * @param p A port structure
  * @param buf Buffer
  * @param bufsize Buffer size
